@@ -58,7 +58,9 @@ _OPTS = [
                help=_('The green thread pool size.')),
     cfg.IntOpt('introspection_delay',
                default=5,
-               help=_('Delay (in seconds) between two introspections.')),
+               help=_('Delay (in seconds) between two introspections. Only '
+                      'applies when boot is managed by ironic-inspector (i.e. '
+                      'manage_boot==True).')),
     cfg.ListOpt('ipmi_address_fields',
                 default=['ilo_address', 'drac_host', 'drac_address',
                          'cimc_address'],
@@ -79,6 +81,9 @@ _OPTS = [
     cfg.BoolOpt('enable_mdns', default=False,
                 help=_('Whether to enable publishing the ironic-inspector API '
                        'endpoint via multicast DNS.')),
+    cfg.BoolOpt('standalone', default=True,
+                help=_('Whether to run ironic-inspector as a standalone '
+                       'service. It\'s EXPERIMENTAL to set to False.'))
 ]
 
 
