@@ -234,6 +234,58 @@ class TestIntrospect(BaseTest):
         cli.node.set_power_state.assert_called_once_with(self.uuid,
                                                          'reboot')
 
+    def test_forced_persistent_boot(self, client_mock, start_mock):
+        self.node.driver_info['force_persistent_boot_device'] = 'Always'
+        cli = self._prepare(client_mock)
+        start_mock.return_value = self.node_info
+
+        introspect.introspect(self.node.uuid)
+
+        cli.node.get.assert_called_once_with(self.uuid)
+        cli.node.validate.assert_called_once_with(self.uuid)
+
+        start_mock.assert_called_once_with(self.uuid,
+                                           bmc_address=[self.bmc_address],
+                                           manage_boot=True,
+                                           ironic=cli)
+        self.node_info.ports.assert_called_once_with()
+        self.node_info.add_attribute.assert_called_once_with('mac',
+                                                             self.macs)
+        self.sync_filter_mock.assert_called_with(cli)
+        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+                                                         'pxe',
+                                                         persistent=True)
+        cli.node.set_power_state.assert_called_once_with(self.uuid,
+                                                         'reboot')
+        self.node_info.acquire_lock.assert_called_once_with()
+        self.node_info.release_lock.assert_called_once_with()
+
+    def test_forced_persistent_boot_compat(self, client_mock, start_mock):
+        self.node.driver_info['force_persistent_boot_device'] = 'true'
+        cli = self._prepare(client_mock)
+        start_mock.return_value = self.node_info
+
+        introspect.introspect(self.node.uuid)
+
+        cli.node.get.assert_called_once_with(self.uuid)
+        cli.node.validate.assert_called_once_with(self.uuid)
+
+        start_mock.assert_called_once_with(self.uuid,
+                                           bmc_address=[self.bmc_address],
+                                           manage_boot=True,
+                                           ironic=cli)
+        self.node_info.ports.assert_called_once_with()
+        self.node_info.add_attribute.assert_called_once_with('mac',
+                                                             self.macs)
+        self.sync_filter_mock.assert_called_with(cli)
+        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+                                                         'pxe',
+                                                         persistent=True)
+        cli.node.set_power_state.assert_called_once_with(self.uuid,
+                                                         'reboot')
+        self.node_info.acquire_lock.assert_called_once_with()
+        self.node_info.release_lock.assert_called_once_with()
+
     def test_no_lookup_attrs(self, client_mock, start_mock):
         cli = self._prepare(client_mock)
         self.node_info.ports.return_value = []
@@ -349,6 +401,24 @@ class TestIntrospect(BaseTest):
         # updated to the current time.time()
         self.assertEqual(42, introspect._LAST_INTROSPECTION_TIME)
 
+    @mock.patch.object(time, 'time', autospec=True)
+    def test_introspection_no_delay_without_manage_boot(self, time_mock,
+                                                        client_mock,
+                                                        start_mock):
+        time_mock.return_value = 42
+        introspect._LAST_INTROSPECTION_TIME = 40
+        CONF.set_override('introspection_delay', 10)
+
+        self._prepare(client_mock)
+        start_mock.return_value = self.node_info
+        self.node_info.manage_boot = False
+
+        introspect.introspect(self.uuid, manage_boot=False)
+
+        self.assertFalse(self.sleep_fixture.mock.called)
+        # not updated
+        self.assertEqual(40, introspect._LAST_INTROSPECTION_TIME)
+
     @mock.patch.object(time, 'time')
     def test_introspection_delay_not_needed(self, time_mock, client_mock,
                                             start_mock):
